@@ -302,6 +302,7 @@ src_support_header_files = Split('''
     lyxalgo.h
     lyxlib.h
     lyxtime.h
+    numpunct_lyx_char_type.h
     Messages.h
     os.h
     os_win32.h
@@ -922,7 +923,6 @@ src_frontends_qt4_ui_files = Split('''
     PrefColorsUi.ui
     PrefCompletionUi.ui
     PrefConvertersUi.ui
-    PrefDateUi.ui
     PrefDisplayUi.ui
     PrefEditUi.ui
     PrefFileformatsUi.ui
@@ -930,6 +930,7 @@ src_frontends_qt4_ui_files = Split('''
     PrefInputUi.ui
     PrefLanguageUi.ui
     PrefLatexUi.ui
+    PrefOutputUi.ui
     PrefPathsUi.ui
     PrefPlaintextUi.ui
     PrefPrinterUi.ui
@@ -1210,6 +1211,7 @@ po_extra_files = Split('''
     ru.po
     Rules-quot
     sk.po
+    sr.po
     sl.po
     sv.po
     tr.po
@@ -1290,14 +1292,17 @@ lib_templates_files = Split('''
     ACM-siggraph.lyx
     ACM-sigplan.lyx
     agu_article.lyx
+    agutex.lyx
     apa.lyx
     beamer-conference-ornate-20min.lyx
     de_beamer-conference-ornate-20min.lyx
     dinbrief.lyx
     docbook_article.lyx
+    ectaart.lyx
     elsarticle.lyx
     es_beamer-conference-ornate-20min.lyx
     fr_beamer-conference-ornate-20min.lyx
+    frletter.lyx
     g-brief-de.lyx
     g-brief-en.lyx
     g-brief2.lyx
@@ -1311,6 +1316,7 @@ lib_templates_files = Split('''
     koma-letter2.lyx
     latex8.lyx
     letter.lyx
+    lettre.lyx
     README.new_templates
     revtex.lyx
     revtex4.lyx
@@ -1590,6 +1596,8 @@ lib_images_math_files = Split('''
     dashv.png
     ddagger.png
     ddot.png
+    dddot.png
+    ddddot.png
     ddots.png
     delim.png
     delta.png
@@ -2121,6 +2129,11 @@ lib_doc_cs_files = Split('''
 ''')
 
 
+lib_doc_da_files = Split('''
+    Intro.lyx
+''')
+
+
 lib_doc_de_files = Split('''
     Customization.lyx
     DummyDocument1.lyx
@@ -2152,11 +2165,10 @@ lib_doc_de_clipart_files = Split('''
 ''')
 
 
-lib_doc_da_files = Split('''
+lib_doc_el_files = Split('''
     Intro.lyx
 ''')
 
-
 lib_doc_es_files = Split('''
     Customization.lyx
     DocumentoPostizo1.lyx
@@ -2461,6 +2473,25 @@ lib_examples_de_files = Split('''
 ''')
 
 
+lib_examples_es_files = Split('''
+    beamer-conference-ornate20min.lyx
+    Braille.lyx
+    ejemplo_con_lyx.lyx
+    ejemplo_sin_lyx.lyx
+    ItemizeBullets.lyx
+    linguistics.lyx
+    multicol.lyx
+    splash.lyx
+    tufte-book.lyx
+    tufte-handout.lyx
+''')
+
+
+lib_examples_el_files = Split('''
+    splash.lyx
+''')
+
+
 lib_examples_fa_files = Split('''
     splash.lyx
 ''')
@@ -2484,20 +2515,6 @@ lib_examples_fr_files = Split('''
 ''')
 
 
-lib_examples_es_files = Split('''
-    beamer-conference-ornate20min.lyx
-    Braille.lyx
-    ejemplo_con_lyx.lyx
-    ejemplo_sin_lyx.lyx
-    ItemizeBullets.lyx
-    linguistics.lyx
-    multicol.lyx
-    splash.lyx
-    tufte-book.lyx
-    tufte-handout.lyx
-''')
-
-
 lib_examples_eu_files = Split('''
     adibide_gordina.lyx
     adibide_lyx-atua.lyx
@@ -2588,6 +2605,11 @@ lib_examples_sl_files = Split('''
 ''')
 
 
+lib_examples_sr_files = Split('''
+    splash.lyx
+''')
+
+
 lib_examples_uk_files = Split('''
     splash.lyx
 ''')
@@ -2632,6 +2654,7 @@ lib_layouts_files = Split('''
     acmsiggraph.layout
     agu-dtd.layout
     agums.layout
+    agutex.layout
     amsart.layout
     amsbook.layout
     apa.layout
@@ -2651,6 +2674,7 @@ lib_layouts_files = Split('''
     docbook.layout
     doublecol-new.layout
     dtk.layout
+    ectaart.layout
     egs.layout
     elsart.layout
     elsarticle.layout
@@ -2661,6 +2685,7 @@ lib_layouts_files = Split('''
     extletter.layout
     extreport.layout
     foils.layout
+    frletter.layout
     g-brief-de.layout
     g-brief-en.layout
     g-brief2.layout
@@ -2682,6 +2707,7 @@ lib_layouts_files = Split('''
     kluwer.layout
     latex8.layout
     letter.layout
+    lettre.layout
     literate-article.layout
     literate-book.layout
     literate-report.layout
