@@ -483,7 +483,7 @@ FuncStatus LyXFunc::getStatus(FuncRequest const & cmd) const
 		flag.setOnOff(enable && !buf->lyxvc().locker().empty());
 		break;
 	case LFUN_VC_REVERT:
-		enable = buf->lyxvc().inUse();
+		enable = !buf->isReadonly() && buf->lyxvc().inUse();
 		break;
 	case LFUN_VC_UNDO_LAST:
 		enable = buf->lyxvc().undoLastEnabled();
@@ -583,7 +583,7 @@ FuncStatus LyXFunc::getStatus(FuncRequest const & cmd) const
 	}
 
 	case LFUN_VC_REPO_UPDATE:
-		enable = buf->lyxvc().inUse();
+		enable = buf->lyxvc().repoUpdateEnabled();
 		break;
 
 	case LFUN_VC_COMMAND: {
@@ -859,11 +859,17 @@ void LyXFunc::dispatch(FuncRequest const & cmd)
 
 		case LFUN_BUFFER_RELOAD: {
 			LASSERT(lyx_view_ && buffer, /**/);
-			docstring const file = makeDisplayPath(buffer->absFileName(), 20);
-			docstring text = bformat(_("Any changes will be lost. Are you sure "
-							     "you want to revert to the saved version of the document %1$s?"), file);
-			int const ret = Alert::prompt(_("Revert to saved document?"),
-				text, 1, 1, _("&Revert"), _("&Cancel"));
+
+			int ret = 0;
+			if (!buffer->isClean()) { 
+				docstring const file = 
+					makeDisplayPath(buffer->absFileName(), 20);
+				docstring text = bformat(_("Any changes will be lost. "
+					"Are you sure you want to revert to the saved version "
+					"of the document %1$s?"), file);
+				ret = Alert::prompt(_("Revert to saved document?"),
+					text, 1, 1, _("&Revert"), _("&Cancel"));
+			}
 
 			if (ret == 0) {
 				buffer->markClean();
@@ -1671,7 +1677,7 @@ void LyXFunc::dispatch(FuncRequest const & cmd)
 		case LFUN_BOOKMARK_GOTO:
 			// go to bookmark, open unopened file and switch to buffer if necessary
 			gotoBookmark(convert<unsigned int>(to_utf8(cmd.argument())), true, true);
-			updateFlags = Update::FitCursor;
+			updateFlags = Update::Force | Update::FitCursor;
 			break;
 
 		case LFUN_BOOKMARK_CLEAR:
@@ -2157,6 +2163,7 @@ void actOnUpdatedPrefs(LyXRC const & lyxrc_orig, LyXRC const & lyxrc_new)
 	case LyXRC::RC_FULL_SCREEN_WIDTH:
 	case LyXRC::RC_VISUAL_CURSOR:
 	case LyXRC::RC_VIEWER:
+	case LyXRC::RC_EXPORT_OVERWRITE:
 	case LyXRC::RC_LAST:
 		break;
 	}
