@@ -329,6 +329,12 @@ docstring InsetMathHull::standardFont() const
 }
 
 
+docstring InsetMathHull::standardColor() const
+{
+	return from_ascii(type_ == hullNone ? "foreground" : "math");
+}
+
+
 bool InsetMathHull::previewState(BufferView * bv) const
 {
 	if (!editing(bv) && RenderPreview::status() == LyXRC::PREVIEW_ON) {
@@ -413,8 +419,11 @@ void InsetMathHull::draw(PainterInfo & pi, int x, int y) const
 		return;
 	}
 
+	bool const really_change_color = pi.base.font.color() == Color_none;
+	ColorChanger dummy0(pi.base.font, standardColor(), really_change_color);
 	FontSetChanger dummy1(pi.base, standardFont());
 	StyleChanger dummy2(pi.base, display() ? LM_ST_DISPLAY : LM_ST_TEXT);
+
 	InsetMathGrid::draw(pi, x + 1, y);
 
 	if (numberedType()) {
@@ -839,12 +848,24 @@ docstring InsetMathHull::nicelabel(row_type row) const
 }
 
 
-void InsetMathHull::glueall()
+void InsetMathHull::glueall(HullType type)
 {
 	MathData ar;
 	for (idx_type i = 0; i < nargs(); ++i)
 		ar.append(cell(i));
+	InsetLabel * label = 0;
+	if (type == hullEquation) {
+		// preserve first non-empty label
+		for (row_type row = 0; row < nrows(); ++row) {
+			if (label_[row]) {
+				label = label_[row];
+				label_[row] = 0;
+				break;
+			}
+		}
+	}
 	*this = InsetMathHull(buffer_, hullSimple);
+	label_[0] = label;
 	cell(0) = ar;
 	setDefaults();
 }
@@ -955,7 +976,7 @@ void InsetMathHull::mutate(HullType newtype)
 			numbered(0, false);
 		} else {
 			setType(hullEquation);
-			numbered(0, false);
+			numbered(0, label_[0] ? true : false);
 			mutate(newtype);
 		}
 	}
@@ -981,24 +1002,7 @@ void InsetMathHull::mutate(HullType newtype)
 
 	else if (type_ == hullEqnArray) {
 		if (newtype < type_) {
-			// set correct (no)numbering
-			nonum_[0] = true;
-			for (row_type row = 0; row < nrows(); ++row) {
-				if (!nonum_[row]) {
-					nonum_[0] = false;
-					break;
-				}
-			}
-
-			// set first non-empty label
-			for (row_type row = 0; row < nrows(); ++row) {
-				if (label_[row]) {
-					label_[0] = label_[row];
-					break;
-				}
-			}
-
-			glueall();
+			glueall(newtype);
 			mutate(newtype);
 		} else { // align & Co.
 			changeCols(2);
@@ -1067,17 +1071,23 @@ void InsetMathHull::mutate(HullType newtype)
 }
 
 
-docstring InsetMathHull::eolString(row_type row, bool fragile) const
+docstring InsetMathHull::eolString(row_type row, bool fragile, bool latex,
+		bool last_eoln) const
 {
 	docstring res;
 	if (numberedType()) {
-		if (label_[row] && !nonum_[row])
-			res += "\\label{" +
-			    escape(label_[row]->getParam("name")) + '}';
+		if (label_[row] && !nonum_[row]) {
+			docstring const name =
+				latex ? escape(label_[row]->getParam("name"))
+				      : label_[row]->getParam("name");
+			res += "\\label{" + name + '}';
+		}
 		if (nonum_[row] && (type_ != hullMultline))
 			res += "\\nonumber ";
 	}
-	return res + InsetMathGrid::eolString(row, fragile);
+	// Never add \\ on the last empty line of eqnarray and friends
+	last_eoln = false;
+	return res + InsetMathGrid::eolString(row, fragile, latex, last_eoln);
 }
 
 
@@ -1397,7 +1407,7 @@ bool InsetMathHull::getStatus(Cursor & cur, FuncRequest const & cmd,
 	case LFUN_MATH_NUMBER_TOGGLE:
 		// FIXME: what is the right test, this or the one of
 		// LABEL_INSERT?
-		status.setEnabled(display());
+		status.setEnabled(display() != Inline);
 		status.setOnOff(numberedType());
 		return true;
 
